==> POE-0.25.tar.gz: POE-0.25/lib/Makefile-5004.pm <==
#!/usr/bin/perl
# $Id: Makefile-5004.pm,v 1.12 2002/09/10 19:55:31 rcaputo Exp $

use ExtUtils::MakeMaker;

# Add a new target.

sub MY::test {
  package MY;
  "\ntest ::\n\t\$(FULLPERL) ./lib/deptest.perl\n" . shift->SUPER::test(@_);
}

sub MY::postamble {
    return <<EOF;
reportupload: poe_report.xml
	perl lib/reportupload.pl

uploadreport: poe_report.xml
	perl lib/reportupload.pl

testreport: poe_report.xml

poe_report.xml: Makefile
	perl lib/testreport.pl
EOF

}

# Touch CHANGES so it exists.
open(CHANGES, ">>CHANGES") and close CHANGES;

WriteMakefile
  ( NAME           => 'POE',
    VERSION_FROM   => 'POE.pm',

    dist           =>
    { COMPRESS => 'gzip -9f',
      SUFFIX   => 'gz',
      PREOP    => ( './lib/cvs-log.perl | ' .
                    'tee ./$(DISTNAME)-$(VERSION)/CHANGES > ./CHANGES'
                  ),
    },
    PREREQ_PM      => { Carp               => 0,
                        Exporter           => 0,
                        IO                 => 0,
                        POSIX              => 0,
                        Socket             => 0,
                        Filter::Util::Call => 1.04,
                      },

    # Remove 'lib', which should have been named 'privlib'.  The 'lib'
    # directory in this distribution is for private stuff needed to
    # build and test POE.  Those things should not be installed!  At
    # some point SourceForge will open up shell access to my CVS tree
    # there, and I will be able to rename the directories within the
    # repository without losing revision histories.  When that
    # happens, I'll rename the 'lib' driectory to 'privlib'.

    PMLIBDIRS      => [ 'POE' ],
  );

1;

==> POE-0.27.tar.gz: POE-0.27/lib/Makefile-5004.pm <==
#!/usr/bin/perl
# $Id: Makefile-5004.pm,v 1.15 2003/06/03 17:39:49 rcaputo Exp $

use ExtUtils::MakeMaker;

# Add a new target.

sub MY::test {
  package MY;
  "\ntest ::\n\t\$(FULLPERL) ./lib/deptest.perl\n" . shift->SUPER::test(@_);
}

sub MY::postamble {
    return <<EOF;
reportupload: poe_report.xml
	perl lib/reportupload.pl

uploadreport: poe_report.xml
	perl lib/reportupload.pl

testreport: poe_report.xml

poe_report.xml: Makefile
	perl lib/testreport.pl
EOF

}

# Touch CHANGES so it exists.
open(CHANGES, ">>CHANGES") and close CHANGES;

WriteMakefile
  ( NAME           => 'POE',
    VERSION_FROM   => 'POE.pm',

    dist           =>
    { COMPRESS => 'gzip -9f',
      SUFFIX   => 'gz',
      PREOP    => ( './lib/cvs-log.perl | ' .
                    'tee ./$(DISTNAME)-$(VERSION)/CHANGES > ./CHANGES'
                  ),
    },
    test           => { TESTS => 't/*/*.t t/*.t' },
    PREREQ_PM      => { Carp               => 0,
                        Exporter           => 0,
                        IO                 => 0,
                        POSIX              => 0,
                        Socket             => 0,
                        Filter::Util::Call => 1.04,
                      },

    # Remove 'lib', which should have been named 'privlib'.  The 'lib'
    # directory in this distribution is for private stuff needed to
    # build and test POE.  Those things should not be installed!  At
    # some point SourceForge will open up shell access to my CVS tree
    # there, and I will be able to rename the directories within the
    # repository without losing revision histories.  When that
    # happens, I'll rename the 'lib' driectory to 'privlib'.

    PMLIBDIRS      => [ 'POE' ],
    clean => {
        FILES => 'poe_report.xml test-output.err coverage.report',
    }
  );

1;
